/********************************************************************************
  for PIC18 processors only - tested on 18F45k22

  How to use:
  
  1. select appropriate cpu speed - (cpu_08_mhz or cpu_32_mhz)
  2. select by defining one or more timers
  2. each timer selection requires assignment to high or low priority interrupts
  4. for each timer selection define interrupt interval for selected cpu speed
  5. for each timer initialise pointer to interrupt routine and call appropriate
     timer initialisation. See example below :

        pt2_timer0_isr = &my_timer0_isr;
        InitTimer0();

        pt2_timer1_isr = &my_timer1_isr;
        InitTimer1();
        
  6. after initialisation interrupts need to be enabled:
  
       GIE_bit     = 1;
       GIEL_bit    = 1;
*********************************************************************************/

//#define cpu_08_mhz
#define cpu_32_mhz

#define hi_priority_enabled   // either or both can be enabled
#define lo_priority_enabled   // either or both can be enabled

//------------------------------//
// select timer(s) - either one //
//   or all can be enabled      //
//------------------------------//
//
//------------//
#define timer0
#define timer1
#define timer2
#define timer3
#define timer4
#define timer5
#define timer6
//------------//

//------------------------------------//
// select priority assignment for     //
// timer(s) - This is strictly either //
// or selection BUT NOT BOTH          //
//------------------------------------//
//
// hi priority selection group
//
#ifdef hi_priority_enabled
//---------------------------//
  //#define timer0_hi_priority
  #define timer1_hi_priority
  #define timer2_hi_priority
  //#define timer3_hi_priority
  #define timer4_hi_priority
  #define timer5_hi_priority
  //#define timer6_hi_priority
//---------------------------//
#endif
//
// low priority selection group
//
#ifdef lo_priority_enabled
//---------------------------//
  #define timer0_lo_priority
  //#define timer1_lo_priority
  //#define timer2_lo_priority
  #define timer3_lo_priority
  //#define timer4_lo_priority
  //#define timer5_lo_priority
  #define timer6_lo_priority
//---------------------------//
#endif

//create all require function pointers
//
#ifdef timer0
  unsigned char (*pt2_timer0_isr) (void);
#endif
#ifdef timer1
  unsigned char (*pt2_timer1_isr) (void);
#endif
#ifdef timer2
  unsigned char (*pt2_timer2_isr) (void);
#endif
#ifdef timer3
  unsigned char (*pt2_timer3_isr) (void);
#endif
#ifdef timer4
  unsigned char (*pt2_timer4_isr) (void);
#endif
#ifdef timer5
  unsigned char (*pt2_timer5_isr) (void);
#endif
#ifdef timer6
  unsigned char (*pt2_timer6_isr) (void);
#endif

//----------------------------------------//
// timer(s) Interrupt interval selection  //
//----------------------------------------//
//
//---  TIMER 0
//
#ifdef timer0  // only one of the below only
  #ifdef cpu_08_mhz
  //-----------------------//
    //#define timer0_25us
    //#define timer0_50us
    //#define timer0_100us
    //#define timer0_1ms
    //#define timer0_10ms
    #define timer0_25ms
    //#define timer0_50ms
    //#define timer0_100ms
  //-----------------------//
    #include "timer-0-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer0_10us
    //#define timer0_25us
    //#define timer0_50us
    //#define timer0_100us
    //#define timer0_1ms
    //#define timer0_10ms
    #define timer0_25ms
    //#define timer0_100ms
    //#define timer0_500ms
    //#define timer0_1s
  //-----------------------//
    #include "timer-0-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer0
//
//---  TIMER 1
//
#ifdef timer1  // only one of the below only
   #ifdef cpu_08_mhz
   //-----------------------//
     //#define timer1_25us
     //--#define timer1_50us
     //#define timer1_100us
     //#define timer1_1ms
     //#define timer1_10ms
     #define timer1_25ms
     //#define timer1_50ms
     //#define timer1_100ms
   //-----------------------//
    #include "timer-1-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer1_10us
    //#define timer1_25us
    //#define timer1_50us
    //#define timer1_100us
    //#define timer1_1ms
    //#define timer1_10ms
    #define timer1_25ms
    //#define timer1_50ms
  //-----------------------//
    #include "timer-1-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer1
//
//---  TIMER 2
//
#ifdef timer2  // only one of the below only
  #ifdef cpu_08_mhz
  //-----------------------//
    //#define timer2_25us
    //#define timer2_50us
    //#define timer2_100us
    //--#define timer2_1ms
    #define timer2_10ms
    //#define timer2_25ms
  //-----------------------//
    #include "timer-2-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer2_10us
    //#define timer2_25us
    //#define timer2_50us
    //#define timer2_100us
    //#define timer2_1ms
    #define timer2_5ms
  //-----------------------//
    #include "timer-2-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer2

//
//---  TIMER 3
//
#ifdef timer3  // only one of the below only
  #ifdef cpu_08_mhz
  //-----------------------//
    //#define timer3_25us
    //#define timer3_50us
    //#define timer3_100us
    //#define timer3_1ms
    //#define timer3_10ms
    //#define timer3_25ms
    #define timer3_50ms
    //#define timer3_100ms
  //-----------------------//
    #include "timer-3-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer3_10us
    //#define timer3_25us
    //#define timer3_50us
    //#define timer3_100us
    //#define timer3_1ms
    //#define timer3_10ms
    #define timer3_25ms
    //#define timer3_50ms
  //-----------------------//
    #include "timer-3-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer3

//
//---  TIMER 4
//
#ifdef timer4  // only one of the below only
  #ifdef cpu_08_mhz
  //-----------------------//
    //--#define timer4_25us
    //#define timer4_50us
    //#define timer4_100us
    //#define timer4_1ms
    //#define timer4_10ms
    #define timer4_25ms
  //-----------------------//
    #include "timer-4-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer4_10us
    #define timer4_25us
    //#define timer4_50us
    //#define timer4_100us
    //#define timer4_1ms
    //#define timer4_5ms
  //-----------------------//
    #include "timer-4-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer4

//
//---  TIMER 5
//
#ifdef timer5  // only one of the below only
  #ifdef cpu_08_mhz
  //-----------------------//
    //#define timer5_25us
    //#define timer5_50us
    //#define timer5_100us
    //#define timer5_1ms
    //#define timer5_10ms
    //#define timer5_25ms
    #define timer5_50ms
    //#define timer5_100ms
  //-----------------------//
    #include "timer-5-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer5_10us
    //#define timer5_25us
    //#define timer5_50us
    //#define timer5_100us
    //#define timer5_1ms
    //#define timer5_10ms
    //#define timer5_25ms
    #define timer5_50ms
  //-----------------------//
    #include "timer-5-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer5

//
//---  TIMER 6
//
#ifdef timer6  // only one of the below only
  #ifdef cpu_08_mhz
    //#define timer6_25us
    //#define timer6_50us
    //#define timer6_100us
    //--#define timer6_1ms
    //#define timer6_10ms
    #define timer6_25ms
  //-----------------------//
    #include "timer-6-def-08Mhz.c"
  #endif  //END==> #ifdef cpu_08_mhz
  #ifdef cpu_32_mhz
  //-----------------------//
    //#define timer6_10us
    //#define timer6_25us
    //#define timer6_50us
    //#define timer6_100us
    //#define timer6_1ms
    #define timer6_5ms
  //-----------------------//
    #include "timer-6-def-32Mhz.c"
  #endif  //END==> #ifdef cpu_32_mhz
#endif //END==> #ifdef timer6


//------------------------------//
// the selection below includes //
// timer Interrupt routines     //
//------------------------------//
//
#ifdef hi_priority_enabled
  #include "Interrupts_Hi.c"
#endif

#ifdef lo_priority_enabled
  #include "Interrupts_Lo.c"
#endif